require 'capistrano/distribution/distributor/abstract_archiver'

module Capistrano
class Distribution
module Distributor

##
# @abstract Subclass and override {#distribute} to create a distributor that
#   extracts archives reachable via +curl+ command.
#
# A convenience class for distributors that extract an archive downloaded using
# the +curl+ command.
class AbstractCurl < AbstractArchiver
  ##
  # Tests whether or not the archive indicated by {#url} is available via the
  # +curl+ command.
  #
  # @return [Boolean] +true+ if the archive is available; otherwise, +false+.
  #
  # @see Abstract#check
  def check
    context.test 'curl', '--fail', '--location', '--silent', '--head', '--request', 'GET', url
  end
end

end
end
end
