require 'capistrano/distribution/distributor/abstract_curl'
require 'capistrano/distribution/distributor/tar_helper'

module Capistrano
class Distribution
module Distributor

##
# Deploys Tar files downloadable using the +curl+ command.
class CurlTar < AbstractCurl
  include TarHelper

  ##
  # Extracts the content rooted under {#subtree} within the Tar file indicated
  # by {#url} to the location indicated by {#release_path}.  The Tar file is
  # extracted as it is downloaded, so no local copy of the Tar file itself is
  # ever created.
  #
  # @return [nil]
  #
  # @see Archiver#distribute
  def distribute
    context.execute 'mkdir', '-p', release_path
    context.execute 'curl', '--fail', '--location', '--silent', url, '|',
                    'tar', '-x',
                    compression_opt,
                    strip_components_opt,
                    '-C', release_path,
                    subtree
    nil
  end
end

end
end
end
